@@ -5,18 +5,18 @@ from django.forms.formsets import formset_factory
 from django.forms.models import modelformset_factory, inlineformset_factory
 from django.views.generic.detail import SingleObjectMixin, SingleObjectTemplateResponseMixin
 from django.views.generic.list import MultipleObjectMixin, MultipleObjectTemplateResponseMixin
-from django.forms.models import BaseInlineFormSet
 
 
-class BaseFormSetMixin(object):
+class BaseFormSetFactory(object):
     """
-    Base class for constructing a FormSet within a view
+    Base class for constructing a FormSet from `formset_factory` in a view.
+
+    Calling `construct_formset` calls all other methods.
     """
 
     initial = []
     form_class = None
     formset_class = None
-    success_url = None
     prefix = None
     formset_kwargs = {}
     factory_kwargs = {}
@@ -102,10 +102,20 @@ class BaseFormSetMixin(object):
         return kwargs
 
 
-class FormSetMixin(BaseFormSetMixin, ContextMixin):
+class BaseFormSetMixin(BaseFormSetFactory):
+    def __init__(self, *args, **kwargs):
+        from warnings import warn
+        warn('`extra_views.BaseFormSetMixin` has been renamed to '
+             '`BaseFormSetFactory`. `BaseFormSetMixin` will be removed in '
+             'a future release.', DeprecationWarning)
+        super(BaseFormSetMixin, self).__init__(*args, **kwargs)
+
+
+class FormSetMixin(BaseFormSetFactory, ContextMixin):
     """
-    A mixin that provides a way to show and handle a formset in a request.
+    A view mixin that provides a way to show and handle a single formset in a request.
     """
+    success_url = None
 
     def get_success_url(self):
         """
@@ -134,31 +144,14 @@ class FormSetMixin(BaseFormSetMixin, ContextMixin):
 
 class ModelFormSetMixin(FormSetMixin, MultipleObjectMixin):
     """
-    A mixin that provides a way to show and handle a model formset in a request.
+    A view mixin that provides a way to show and handle a single model formset in a request.
+
+    Uses `modelformset_factory`.
     """
 
     exclude = None
     fields = None
 
-    def get_context_data(self, **kwargs):
-        """
-        If an object list has been supplied, inject it into the context with the
-        supplied context_object_name name.
-        """
-        context = {}
-
-        if self.object_list is not None:
-            context['object_list'] = self.object_list
-            context_object_name = self.get_context_object_name(self.object_list)
-            if context_object_name:
-                context[context_object_name] = self.object_list
-        context.update(kwargs)
-
-        # MultipleObjectMixin get_context_data() doesn't work when object_list
-        # is not provided in kwargs, so we skip MultipleObjectMixin and call
-        # ContextMixin directly.
-        return ContextMixin.get_context_data(self, **context)
-
     def get_formset_kwargs(self):
         """
         Returns the keyword arguments for instantiating the formset.
@@ -177,8 +170,6 @@ class ModelFormSetMixin(FormSetMixin, MultipleObjectMixin):
 
         if self.get_form_class():
             kwargs['form'] = self.get_form_class()
-        if self.get_formset_class():
-            kwargs['formset'] = self.get_formset_class()
         return kwargs
 
     def get_formset(self):
@@ -195,31 +186,17 @@ class ModelFormSetMixin(FormSetMixin, MultipleObjectMixin):
         return super(ModelFormSetMixin, self).formset_valid(formset)
 
 
-class BaseInlineFormSetMixin(BaseFormSetMixin):
+class BaseInlineFormSetFactory(BaseFormSetFactory):
     """
-    Base class for constructing an inline formSet within a view
+    Base class for constructing a FormSet from `inlineformset_factory` in a view.
+
+    Calling `construct_formset` calls all other methods.
     """
     model = None
     inline_model = None
-    formset_class = BaseInlineFormSet
     exclude = None
     fields = None
 
-    def get_context_data(self, **kwargs):
-        """
-        If an object has been supplied, inject it into the context with the
-        supplied context_object_name name.
-        """
-        context = {}
-
-        if self.object:
-            context['object'] = self.object
-            context_object_name = self.get_context_object_name(self.object)
-            if context_object_name:
-                context[context_object_name] = self.object
-        context.update(kwargs)
-        return super(BaseInlineFormSetMixin, self).get_context_data(**context)
-
     def get_inline_model(self):
         """
         Returns the inline model to use with the inline formset
@@ -237,7 +214,7 @@ class BaseInlineFormSetMixin(BaseFormSetMixin):
                 'Setting `{0}.save_as_new` at the class level is now '
                 'deprecated. Set `{0}.formset_kwargs` instead.'.format(klass)
             )
-        kwargs = super(BaseInlineFormSetMixin, self).get_formset_kwargs()
+        kwargs = super(BaseInlineFormSetFactory, self).get_formset_kwargs()
         kwargs['instance'] = self.object
         return kwargs
 
@@ -245,14 +222,12 @@ class BaseInlineFormSetMixin(BaseFormSetMixin):
         """
         Returns the keyword arguments for calling the formset factory
         """
-        kwargs = super(BaseInlineFormSetMixin, self).get_factory_kwargs()
+        kwargs = super(BaseInlineFormSetFactory, self).get_factory_kwargs()
         kwargs.setdefault('fields', self.fields)
         kwargs.setdefault('exclude', self.exclude)
 
         if self.get_form_class():
             kwargs['form'] = self.get_form_class()
-        if self.get_formset_class():
-            kwargs['formset'] = self.get_formset_class()
         return kwargs
 
     def get_formset(self):
@@ -262,9 +237,18 @@ class BaseInlineFormSetMixin(BaseFormSetMixin):
         return inlineformset_factory(self.model, self.get_inline_model(), **self.get_factory_kwargs())
 
 
-class InlineFormSetMixin(BaseInlineFormSetMixin, FormSetMixin, SingleObjectMixin):
+class BaseInlineFormSetMixin(BaseInlineFormSetFactory):
+    def __init__(self, *args, **kwargs):
+        from warnings import warn
+        warn('`extra_views.BaseInlineFormSetMixin` has been renamed to '
+             '`BaseInlineFormSetFactory`. `BaseInlineFormSetMixin` will be removed in '
+             'a future release.', DeprecationWarning)
+        super(BaseInlineFormSetMixin, self).__init__(*args, **kwargs)
+
+
+class InlineFormSetMixin(BaseInlineFormSetFactory, SingleObjectMixin, FormSetMixin):
     """
-    A mixin that provides a way to show and handle a inline formset in a request.
+    A view mixin that provides a way to show and handle a single inline formset in a request.
     """
 
     def formset_valid(self, formset):
